Key Features

P0 - Must Have (Core Platform)

Multi-Source Connectors

Ingest from Confluence, SharePoint, OneDrive, email

Intelligent Chunking

Semantic document segmentation for retrieval

Vector Embedding Pipeline

Embeddings using Qwen gte-Qwen2 models

Hybrid Search

Vector + keyword search (Elasticsearch)

RAG API Endpoint

REST/GraphQL API for AI agents

Access Control

Azure AD SSO with RBAC enforcement

P1/P2 - Enhanced Features

Employee Search Portal

Natural language search (CN/EN)

Knowledge Graph

Relationship mapping via Alibaba GDB

Content Freshness

Auto-detect stale content

Usage Analytics

Search patterns via Cloud Monitor

Feedback Loop

Thumbs up/down to improve retrieval

AI Maintenance Agent

Auto-update and curate content